==> mediacentral-publish-0.2.0.tgz: package/README.md <==
[![pipeline status](https://burl-gitlab.global.avidww.com/avid/dtk/mediacentral-publish/badges/master/pipeline.svg)](https://burl-gitlab.global.avidww.com/avid/dtk/mediacentral-publish/commits/master)
[![coverage report](https://burl-gitlab.global.avidww.com/avid/dtk/mediacentral-publish/badges/master/coverage.svg)](https://burl-gitlab.global.avidww.com/avid/dtk/mediacentral-publish/commits/master)

# Motivation
A tool to publish a project to avid marketplace.

## Usage

1. As a CLI (Install globally)
```js
    npm i -g mediacentral-publish
```
2. As a JS module

```js
const publish = require('mediacentral-publish')
publish(options)
```
## Api

### `publish([, options])`

Parameters

- `options` -- options object with keys:
  - `project` -- path to a project config file  
  - `config` -- path to a project config file (optional if the config is project/src/project.config.json)
    - `version` -- version of your app
    - `developer ID` -- your developer ID (optional)
    - `organization` -- name of you organization
    - `privateKeyPath` -- Path to your private key
    - `appID` - your Application ID
  - `name` -- project name (optional if the name is in a project/src/project.json file under identity.appName)  
  - `password` -- password to ssh private key  
  - `buildImage` -- bool 
  - `build` -- bool
  - `service` -- bool

**Check our CloudUX examples on [Avid-Technology Github](https://github.com/avid-technology)**

**Check our [Quick Start](http://developer.avid.com/quickStart.html) for CloudUX**


## Latest Changes


### [0.2.0](https://burl-gitlab.global.avidww.com/avid/dtk/mediacentral-publish/compare/v0.0.65...v0.2.0) (2019-11-14)


#### Features

* **chart:** [DTKT-730](https://avid-ondemand.atlassian.net/browse/DTKT-730) 'chartDir' option for custom chart templates ([f331c51](https://burl-gitlab.global.avidww.com/avid/dtk/mediacentral-publish/commit/f331c51c6736dd928aabf478dade9307d631d447))


#### [0.0.65](https://burl-gitlab.global.avidww.com/avid/dtk/mediacentral-publish/compare/v0.0.64...v0.0.65) (2019-10-20)


#### Bug Fixes

* [DTKT-729](https://avid-ondemand.atlassian.net/browse/DTKT-729) feature install fails because of wrong configmap template variable ([155fc3a](https://burl-gitlab.global.avidww.com/avid/dtk/mediacentral-publish/commit/155fc3ae8f35071cd78865a5316c9a8a4597bcb8
))

==> mediacentral-publish-0.3.9.tgz: package/README.md <==
[![pipeline status](https://burl-gitlab.global.avidww.com/avid/dtk/mediacentral-publish/badges/master/pipeline.svg)](https://burl-gitlab.global.avidww.com/avid/dtk/mediacentral-publish/commits/master)
[![coverage report](https://burl-gitlab.global.avidww.com/avid/dtk/mediacentral-publish/badges/master/coverage.svg)](https://burl-gitlab.global.avidww.com/avid/dtk/mediacentral-publish/commits/master)

# Motivation
A tool to publish a project to avid marketplace.

## Usage

1. As a CLI (Install globally)
```js
    npm i -g mediacentral-publish
```
2. As a JS module

```js
const publish = require('mediacentral-publish')
publish(options)
```
## Api

### `publish([, options])`

Parameters

- `options` -- options object with keys:
  - `project` -- path to a project config file  
  - `config` -- path to a project config file (optional if the config is project/src/project.config.json)
    - `version` -- version of your app
    - `developer ID` -- your developer ID (optional)
    - `organization` -- name of you organization
    - `privateKeyPath` -- Path to your private key
    - `appID` - your Application ID
  - `name` -- project name (optional if the name is in a project/src/project.json file under identity.appName)  
  - `password` -- password to ssh private key  
  - `buildImage` -- bool 
  - `build` -- bool
  - `service` -- bool

**Check our CloudUX examples on [Avid-Technology Github](https://github.com/avid-technology)**

**Check our [Quick Start](http://developer.avid.com/quickStart.html) for CloudUX**


## Latest Changes

## 0.3.6 (2022-10-12)

### Changes 
* Added vendor field inside metadata.json file. 


## 0.3.5 (2022-07-13)

### Bug Fixes 
* feature install fails beacuse of missing config yaml file for env variables.


## 0.3.4 (2022-07-12)

### Changes 
* Fixed env variables. 


## 0.3.3 (2022-03-15)

### Changes 
* Made AppSecret field optional. 


## 0.3.1 (2021-06-30)

### Changes 
* Updated dependencies. Decreased vulnerabilities amount. 


## [0.2.0](https://burl-gitlab.global.avidww.com/avid/dtk/mediacentral-publish/compare/v0.0.65...v0.2.0) (2019-11-14)

### Features

* **chart:** [DTKT-730](https://avid-ondemand.atlassian.net/browse/DTKT-730) 'chartDir' option for custom chart templates ([f331c51](https://burl-gitlab.global.avidww.com/avid/dtk/mediacentral-publish/commit/f331c51c6736dd928aabf478dade9307d631d447))


### [0.0.65](https://burl-gitlab.global.avidww.com/avid/dtk/mediacentral-publish/compare/v0.0.64...v0.0.65) (2019-10-20)
 
### Bug Fixes

* [DTKT-729](https://avid-ondemand.atlassian.net/browse/DTKT-729) feature install fails because of wrong configmap template variable ([155fc3a](https://burl-gitlab.global.avidww.com/avid/dtk/mediacentral-publish/commit/155fc3ae8f35071cd78865a5316c9a8a4597bcb8))
